==> vee_1.9-0.tar.gz: vee-1.9/src/Menu.py <==
# -*- coding: utf-8 -*-

GLADEFILE = "vee.glade"

import os, gtk
import WIDGET, Conf, TAB, Dialog, child, i18n, \
	Bookmarks as BookmarkData, UID, Panel

_ = i18n.gettext()

def on_show_popup_bookmarks (obj, event, STATE, BOOKMARKS) :

	if event.button == 3 :
		Bookmarks(obj, event, state=STATE, bookmarks=BOOKMARKS)

def on_show_popup_compact (obj, event, STATE) :

	if event.button == 3 :
		Compact(event, state=STATE)

def on_show_popup_full \
		(obj, event, WIDGET_ROOT, STATE, callback_functions, \
		completion_liststore) :

	if event.button == 3 :
		Full( \
			event, \
			widget_root=WIDGET_ROOT, \
			state=STATE,
			callback_functions=callback_functions, \
			completion_liststore=completion_liststore \
		)

class Full (WIDGET.WIDGET) :

	STATE = None
	NOTEBOOK = None
	LIST_TAB = list()
	CURRENT_PAGE = 0
	WIDGET = None

	CALLBACK_FUNCTIONS = dict()
	LISTSTORE_COMPLETION = None

	def __init__ (self, event, **kwargs) :

		if not kwargs.has_key("completion_liststore") :
			raise ValueError, _("completion must be included.")
		else :
			self.LISTSTORE_COMPLETION = kwargs["completion_liststore"]

		if not kwargs.has_key("widget_root") :
			raise ValueError, _("widget_root must be included.")
		else :
			__widget_root = kwargs["widget_root"]

		if not kwargs.has_key("callback_functions") :
			raise ValueError, _("callback_functions must be included.")
		else :
			self.CALLBACK_FUNCTIONS = kwargs["callback_functions"]

		if not kwargs.has_key("state") :
			raise ValueError, _("state must be included.")
		else :
			self.STATE = kwargs["state"]
			self.NOTEBOOK = self.STATE.DATA["notebook"]
			self.LIST_TAB = self.STATE.DATA["tab-list"]
			self.CURRENT_PAGE = self.NOTEBOOK.get_current_page()

		handler = { \
			"on_insert_vim" : self.on_insert_vim, \
			"on_insert_gvim" : self.on_insert_gvim, \
			"on_insert_terminal" : self.on_insert_terminal, \
			"on_preferences" : self.on_preferences, \
			\
			"on_show_toolbar" : self.on_show_toolbar, \
			"on_show_menubar" : self.on_show_menubar, \
			"on_show_bookmark" : self.on_show_bookmark, \
			\
			"on_fileselection_dialog" : self.on_fileselection_dialog,
			"on_external_command" : self.on_external_command,
			\
			"on_quit_all" : self.on_quit_all,
		}

		WIDGET.WIDGET.__init__(self, "menu_full", __widget_root)

		self.WIDGET_SELF.popup(None,None,None,event.button,event.time)

		# set the current state.
		__w = self.xml.get_widget("show_toolbar")
		__w.set_property( \
				"active", self.STATE.DATA["toolbar"].get_property("visible"))

		__w = self.xml.get_widget("show_bookmark")
		__w.set_property( \
				"active", self.STATE.DATA["panel-bookmark"].get_property("visible"))

		__w = self.xml.get_widget("show_menubar")
		__w.set_property( \
				"active", self.STATE.DATA["menubar"].get_property("visible"))

		self.xml.signal_autoconnect(handler)

	def on_external_command (self, widget) :
		Dialog.ExternalCommand( \
			state=self.STATE, \
			callback_functions=self.CALLBACK_FUNCTIONS, \
			completion_liststore=self.LISTSTORE_COMPLETION \
		)

	def on_fileselection_dialog (self, widget) :

		Dialog.FileSelectionDialog( \
			state=self.STATE, \
			callback_functions=self.CALLBACK_FUNCTIONS \
		)

	def on_quit_all (self, widget) :

		Dialog.AskCloseAllTabDialog(self.WIDGET_ROOT, self.STATE)

	def on_insert_vim (self, widget) :
		__func = self.CALLBACK_FUNCTIONS["addPage"]
		__func("vim")

		return True

	def on_insert_gvim (self, widget) :
		__func = self.CALLBACK_FUNCTIONS["addPage"]
		__func("gvim")

		return True

	def on_insert_terminal (self, widget) :
		__func = self.CALLBACK_FUNCTIONS["addPage"]
		__func("terminal")

		return True

	def on_preferences (self, widget) :
		Dialog.Preference()

	def on_show_toolbar (self, widget) :
		__toolbar = self.STATE.DATA["toolbar"]
		if __toolbar.get_property("visible") :
			__toolbar.hide()
		else :
			__toolbar.show()

	def on_show_menubar (self, widget) :
		__menubar = self.STATE.DATA["menubar"]
		if __menubar.get_property("visible") :
			__menubar.hide()
		else :
			__menubar.show()

	def on_show_bookmark (self, widget) :
		box = self.STATE.DATA["panel-bookmark"]

		if box.get_property("visible") :
			box.hide()
		else :
			box.show()

class Compact (WIDGET.WIDGET) :

	STATE = None

	def __init__ (self, event, **kwargs) :

		if not kwargs.has_key("state") :
			raise ValueError, _("state must be included.")
		else :
			self.STATE = kwargs["state"]

		handler = { \
			"on_show_toolbar" : self.on_show_toolbar, \
			"on_show_menubar" : self.on_show_menubar, \
			"on_preferences" : self.on_preferences, \
		}

		WIDGET.WIDGET.__init__(self, "menu_compact", None)

		self.WIDGET_SELF.popup(None,None,None,event.button,event.time)

		# set the current state.
		for i in self.WIDGET_SELF.get_children() :
			if i.get_property("name") == "show_toolbar" :
				i.set_property( \
					"active", self.STATE.DATA["toolbar"].get_property("visible"))

			if i.get_property("name") == "show_menubar" :
				i.set_property( \
					"active", self.STATE.DATA["menubar"].get_property("visible"))

		self.xml.signal_autoconnect(handler)

	def on_show_toolbar (self, widget) :
		__toolbar = self.STATE.DATA["toolbar"]
		if __toolbar.get_property("visible") :
			__toolbar.hide()
		else :
			__toolbar.show()

	def on_show_menubar (self, widget) :
		__menubar = self.STATE.DATA["menubar"]
		if __menubar.get_property("visible") :
			__menubar.hide()
		else :
			__menubar.show()

	def on_preferences (self, widget) :
		Dialog.Preference()

class Bookmarks (WIDGET.WIDGET) :

	BOOKMARKS = None
	STATE = None

	TREEVIEW = None
	TREESTORE = None
	TREEITER = None

	PATH = tuple()

	def __init__ (self, treeview, event, **kwargs) :

		if not kwargs.has_key("bookmarks") :
			raise RuntimeError, "bookmarks must be give."
		else :
			self.BOOKMARKS = kwargs["bookmarks"]

		if not kwargs.has_key("state") :
			raise RuntimeError, "state must be give."
		else :
			self.STATE = kwargs["state"]

		handler = { \
			"on_delete" : self.on_delete, \
			"on_add_current" : self.on_add_current, \
			"on_add_category" : self.on_add_category, \
			"on_rename" : self.on_rename, \
		}

		WIDGET.WIDGET.__init__(self, "menu_bookmarks", None, handler)

		self.WIDGET_SELF.popup(None,None,None,event.button,event.time)

		self.WIDGET_RENAME = self.xml.get_widget("rename1")
		self.WIDGET_DELETE = self.xml.get_widget("delete1")

		self.TREEVIEW = treeview

		(self.TREESTORE, self.TREEITER) = \
			self.TREEVIEW.get_selection().get_selected()

		if not self.TREEITER :
			self.WIDGET_RENAME.hide()
			self.WIDGET_DELETE.hide()
		else :
			self.PATH = self.TREESTORE.get_path(self.TREEITER)

		self.__create_icons()

	def __get_uid (self) :
		uid = self.TREESTORE.get_value(self.TREEITER, Panel.COLUMN_UID)
		return uid

	def on_add_current (self, widget) :
		__list_tab = self.STATE.get_value("tab-list")
		if len(__list_tab) < 1 :
			return False

		__notebook = self.STATE.get_value("notebook")
		__current_page = __notebook.get_current_page()
		__tab = __list_tab[__current_page]

		# get type, value, label
		__t = __tab.Child.CHILD_TYPE
		if __t == child.TYPE_TERMINAL :
			__type = "terminal"
			__value = __tab.Child.DIRECTORY
			__icon = self.ICON_TERMINAL
		elif __t == child.TYPE_VIM :
			__type = "vim"
			__value = __tab.Child.FILENAME
			__icon = self.ICON_VIM
		elif __t == child.TYPE_GVIM :
			__type = "gvim"
			__value = __tab.Child.FILENAME
			__icon = self.ICON_GVIM
		else :
			return

		if not __value.strip() : return

		# get current tab information.
		__uid = UID.get()

		__iter = self.TREESTORE.append( \
			self.TREEITER, [_("New Item"), __icon, __uid])
		__path = self.TREEVIEW.get_model().get_path(__iter)

		if not self.BOOKMARKS.add( \
				__path, __type, __value, _("New Item"), __uid) :
			return False

		# set cell as editing mode for label.
		if self.TREEITER :
			self.TREEVIEW.expand_row(self.PATH, False)

		column = self.TREEVIEW.get_column(0)
		cell = column.get_cell_renderers()[1]
		cell.set_property("editable", True)
		self.TREEVIEW.set_cursor(__path, column, gtk.TRUE)

		# show the item related items.
		self.WIDGET_RENAME.show()
		self.WIDGET_DELETE.show()

	def on_add_category (self, widget) :

		__uid = UID.get()
		__iter = self.TREESTORE.append(\
			None, [_("New Category"), self.ICON_CATEGORY, __uid])
		__path = self.TREEVIEW.get_model().get_path(__iter)

		if not self.BOOKMARKS.add( \
				__path, "category", None, _("New Category"), __uid) :
			return False

		column = self.TREEVIEW.get_column(0)
		cell = column.get_cell_renderers()[1]
		cell.set_property("editable", True)

		self.TREEVIEW.set_cursor(__path, column, gtk.TRUE)

		# show the item related items.
		self.WIDGET_RENAME.show()
		self.WIDGET_DELETE.show()

		# show the item related items.
		self.WIDGET_RENAME.show()
		self.WIDGET_DELETE.show()

	def on_delete (self, widget) :
		self.TREESTORE.remove(self.TREEITER)
		self.BOOKMARKS.remove(self.PATH)

	def on_rename (self, widget) :
		column = self.TREEVIEW.get_column(0)
		cell = column.get_cell_renderers()[1]
		cell.set_property("editable", True)
		self.TREEVIEW.set_cursor(self.PATH, column, gtk.TRUE)

	def __create_icons (self) :
		__i = gtk.Image()
		__i.set_from_file(os.path.join(Conf.DIR_PIXMAPS, "category.png"))
		__image = __i.get_pixbuf().scale_simple(30, 30, 2)
		self.ICON_CATEGORY = __image

		__i = gtk.Image()
		__i.set_from_file(os.path.join(Conf.DIR_PIXMAPS, "terminal.png"))
		__image = __i.get_pixbuf().scale_simple(30, 30, 2)
		self.ICON_TERMINAL = __image

		__i = gtk.Image()
		__i.set_from_file(os.path.join(Conf.DIR_PIXMAPS, "vim.png"))
		__image = __i.get_pixbuf().scale_simple(30, 30, 2)
		self.ICON_VIM = __image

		__i = gtk.Image()
		__i.set_from_file(os.path.join(Conf.DIR_PIXMAPS, "gvim.png"))
		__image = __i.get_pixbuf().scale_simple(30, 30, 2)
		self.ICON_GVIM = __image

"""
Description
-----------


ChangeLog
---------


Usage
-----


"""

__author__ =  "Spike^ekipS <spikeekips@gmail.com>"
__version__=  "0.1"
__nonsense__ = ""

__file__ = "Menu.py"

==> vee_2.2-1.tar.gz: vee-2.2/src/Menu.py <==
# -*- coding: utf-8 -*-
#    Copyright (C) 2005 Spike^ekipS <spikeekips@gmail.com>
#
#    http://vee.kldp.net
#
#       This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


GLADEFILE = "vee.glade"

import os, gtk
import WIDGET, Conf, GConf, TAB, Dialog, child, i18n, \
	Bookmarks as BookmarkData, UID, Panel, Window

_ = i18n.gettext()

def on_show_popup_bookmarks (obj, event, STATE, BOOKMARKS) :

	if event.button == 3 :
		Bookmarks(obj, event, state=STATE, bookmarks=BOOKMARKS)

def on_show_popup_vte \
		(obj, event, WIDGET_ROOT, callback_functions) :

	if event.button == 3 :
		VTE( \
			event, \
			widget_root=WIDGET_ROOT, \
			callback_functions=callback_functions \
		)

def on_show_popup_full \
		(obj, event, WIDGET_ROOT, STATE, callback_functions, \
		completion_liststore) :

	if event.button == 3 :
		Full( \
			event, \
			widget_root=WIDGET_ROOT, \
			state=STATE,
			callback_functions=callback_functions, \
			completion_liststore=completion_liststore \
		)

class VTE (WIDGET.WIDGET) :

	STATE = None
	NOTEBOOK = None
	LIST_TAB = list()
	CURRENT_PAGE = 0
	WIDGET = None

	CALLBACK_FUNCTIONS = dict()
	LISTSTORE_COMPLETION = None

	def __init__ (self, event, **kwargs) :

		if not kwargs.has_key("widget_root") :
			raise ValueError, _("widget_root must be included.")
		else :
			__widget_root = kwargs["widget_root"]

		if not kwargs.has_key("callback_functions") :
			raise ValueError, _("callback_functions must be included.")
		else :
			self.CALLBACK_FUNCTIONS = kwargs["callback_functions"]

		handler = { \
		}

		WIDGET.WIDGET.__init__(self, "menu_vte", __widget_root)

		self.WIDGET_SELF.popup(None,None,None,event.button,event.time)

		self.GCONF_CLIENT = GConf.Client()
		self.GCONF_CLIENT.add_dir(Conf.LOCAL_ROOT)

		self.xml.signal_autoconnect(handler)

		# add im input modules menu.
		__menu_input_methods = WIDGET.get_widget_from_xml("menu_input_method")
		self.WIDGET_ROOT.im_append_menuitems(__menu_input_methods)

		__item_input_method = self.xml.get_widget("input_methods1")
		__item_input_method.get_child()
		__item_input_method.get_children()[0].set_label(_("Input Mehtods"))
		__item_input_method.set_submenu(__menu_input_methods)

		self.WIDGET_SELF.append(__item_input_method)

class Full (WIDGET.WIDGET) :

	STATE = None
	NOTEBOOK = None
	LIST_TAB = list()
	CURRENT_PAGE = 0
	WIDGET = None

	CALLBACK_FUNCTIONS = dict()
	LISTSTORE_COMPLETION = None

	def __init__ (self, event, **kwargs) :

		if not kwargs.has_key("completion_liststore") :
			raise ValueError, _("completion must be included.")
		else :
			self.LISTSTORE_COMPLETION = kwargs["completion_liststore"]

		if not kwargs.has_key("widget_root") :
			raise ValueError, _("widget_root must be included.")
		else :
			__widget_root = kwargs["widget_root"]

		if not kwargs.has_key("callback_functions") :
			raise ValueError, _("callback_functions must be included.")
		else :
			self.CALLBACK_FUNCTIONS = kwargs["callback_functions"]

		if not kwargs.has_key("state") :
			raise ValueError, _("state must be included.")
		else :
			self.STATE = kwargs["state"]
			self.NOTEBOOK = self.STATE.DATA["notebook"]
			self.LIST_TAB = self.STATE.DATA["tab-list"]
			self.CURRENT_PAGE = self.NOTEBOOK.get_current_page()

		handler = { \
			"on_insert_vim" : self.on_insert_vim, \
			"on_insert_gvim" : self.on_insert_gvim, \
			"on_insert_terminal" : self.on_insert_terminal, \
			"on_preferences" : self.on_preferences, \
			\
			"on_show_toolbar" : self.on_show_toolbar, \
			"on_show_statusbar" : self.on_show_statusbar, \
			"on_show_menubar" : self.on_show_menubar, \
			"on_show_bookmark" : self.on_show_bookmark, \
			\
			"on_fileselection_dialog" : self.on_fileselection_dialog,
			"on_external_command" : self.on_external_command,
			\
			"on_quit_all" : self.on_quit_all,
		}

		WIDGET.WIDGET.__init__(self, "menu_full", __widget_root)

		self.WIDGET_SELF.popup(None,None,None,event.button,event.time)

		self.GCONF_CLIENT = GConf.Client()
		self.GCONF_CLIENT.add_dir(Conf.LOCAL_ROOT)

		# set the current state.
		__w = self.xml.get_widget("show_toolbar")
		__w.set_property( \
				"active", self.STATE.DATA["toolbar"].get_property("visible"))

		__w = self.xml.get_widget("show_bookmark")
		__w.set_property( \
				"active", self.STATE.DATA["panel-bookmark"].get_property("visible"))

		__w = self.xml.get_widget("show_statusbar")
		__w.set_property( \
				"active", self.STATE.DATA["statusbar"].INSTANCE_STATUSBAR.get_property("visible"))

		__w = self.xml.get_widget("show_menubar")
		__w.set_property( \
				"active", self.STATE.DATA["menubar"].get_property("visible"))

		self.xml.signal_autoconnect(handler)

		self.__set_menu_label()

		# set the child usabilities.
		__item_vim = self.xml.get_widget("new_vim1")
		__item_gvim = self.xml.get_widget("new_gvim2")
		__item_terminal = self.xml.get_widget("new_terminal1")

		if not self.GCONF_CLIENT.get_value_by_conf("use-vim") :
			__item_vim.hide()
		if not self.GCONF_CLIENT.get_value_by_conf("use-gvim") :
			__item_gvim.hide()
		if not self.GCONF_CLIENT.get_value_by_conf("use-terminal") :
			__item_terminal.hide()


	def __set_menu_label (self) :
		__items = { \
			"new_vim1" : _("New _VIM"),
			"new_gvim2" : _("New _GVIM"),
			"new_terminal1" : _("New _Terminal"),
			"run_command1" : _("Run _Command"),
			"open_file(s)1" : _("Open _File(s)"),
			"show_menubar" : _("Show menubar"),
			"show_toolbar" : _("Show toolbar"),
			"show_statusbar" : _("Show statusbar"),
			"show_bookmark" : _("Show bookmark"),
			"preferences2" : _("Preferences"),
			"toggle1" : _("Toggle"),
			"quit1" : _("Quit"),
		}

		for i, j in __items.items() :
			try :
				self.xml.get_widget(i).get_children()[0].set_label(j)
			except AttributeError :
				continue

	def on_external_command (self, widget) :
		Window.ExternalCommand( \
			state=self.STATE, \
			callback_functions=self.CALLBACK_FUNCTIONS, \
			completion_liststore=self.LISTSTORE_COMPLETION \
		)

	def on_fileselection_dialog (self, widget) :

		Dialog.FileSelectionDialog( \
			state=self.STATE, \
			callback_functions=self.CALLBACK_FUNCTIONS \
		)

	def on_quit_all (self, widget) :

		Dialog.AskCloseAllTabDialog(self.WIDGET_ROOT, self.STATE)

	def on_insert_vim (self, widget) :
		__func = self.CALLBACK_FUNCTIONS["addPage"]
		__func("vim")

		return True

	def on_insert_gvim (self, widget) :
		__func = self.CALLBACK_FUNCTIONS["addPage"]
		__func("gvim")

		return True

	def on_insert_terminal (self, widget) :
		__func = self.CALLBACK_FUNCTIONS["addPage"]
		__func("terminal")

		return True

	def on_preferences (self, widget) :
		Window.Preferences()

	def on_show_statusbar (self, widget) :
		__statusbar = self.STATE.DATA["statusbar"].INSTANCE_STATUSBAR
		if __statusbar.get_property("visible") :
			__statusbar.hide()
		else :
			__statusbar.show()

		cnxid = self.STATE.get_value("gconf-notify-cnxid-statusbar")
		self.GCONF_CLIENT.CLIENT.notify_remove(cnxid)

	def on_show_toolbar (self, widget) :
		__toolbar = self.STATE.DATA["toolbar"]
		if __toolbar.get_property("visible") :
			__toolbar.hide()
		else :
			__toolbar.show()

		cnxid = self.STATE.get_value("gconf-notify-cnxid-toolbar")
		self.GCONF_CLIENT.CLIENT.notify_remove(cnxid)

	def on_show_menubar (self, widget) :
		__menubar = self.STATE.DATA["menubar"]
		if __menubar.get_property("visible") :
			__menubar.hide()
		else :
			__menubar.show()

		cnxid = self.STATE.get_value("gconf-notify-cnxid-menubar")
		self.GCONF_CLIENT.CLIENT.notify_remove(cnxid)

	def on_show_bookmark (self, widget) :
		box = self.STATE.DATA["panel-bookmark"]

		if box.get_property("visible") :
			box.hide()
		else :
			box.show()

		cnxid = self.STATE.get_value("gconf-notify-cnxid-bookmark")
		self.GCONF_CLIENT.CLIENT.notify_remove(cnxid)

class Bookmarks (WIDGET.WIDGET) :

	BOOKMARKS = None
	STATE = None

	TREEVIEW = None
	TREESTORE = None
	TREEITER = None

	PATH = tuple()

	def __init__ (self, treeview, event, **kwargs) :

		if not kwargs.has_key("bookmarks") :
			raise RuntimeError, "bookmarks must be give."
		else :
			self.BOOKMARKS = kwargs["bookmarks"]

		if not kwargs.has_key("state") :
			raise RuntimeError, "state must be give."
		else :
			self.STATE = kwargs["state"]

		handler = { \
			"on_delete" : self.on_delete, \
			"on_add_current" : self.on_add_current, \
			"on_add_category" : self.on_add_category, \
			"on_rename" : self.on_rename, \
		}

		WIDGET.WIDGET.__init__(self, "menu_bookmarks", None, handler)

		self.WIDGET_SELF.popup(None,None,None,event.button,event.time)

		self.WIDGET_RENAME = self.xml.get_widget("rename1")
		self.WIDGET_DELETE = self.xml.get_widget("delete1")

		self.TREEVIEW = treeview

		(self.TREESTORE, self.TREEITER) = \
			self.TREEVIEW.get_selection().get_selected()

		if not self.TREEITER :
			self.WIDGET_RENAME.hide()
			self.WIDGET_DELETE.hide()
		else :
			self.PATH = self.TREESTORE.get_path(self.TREEITER)

		self.__create_icons()

	def __get_uid (self) :
		uid = self.TREESTORE.get_value(self.TREEITER, Panel.COLUMN_UID)
		return uid

	def on_add_current (self, widget) :
		__list_tab = self.STATE.get_value("tab-list")
		if len(__list_tab) < 1 :
			return False

		__notebook = self.STATE.get_value("notebook")
		__current_page = __notebook.get_current_page()
		__tab = __list_tab[__current_page]

		# get type, value, label
		__t = __tab.Child.CHILD_TYPE
		if __t == child.TYPE_TERMINAL :
			__type = "terminal"
			__value = __tab.Child.DIRECTORY
			__icon = self.ICON_TERMINAL
		elif __t == child.TYPE_EXTERNAL_COMMAND :
			__type = "external_command"
			__value = __tab.Child.EXTERNAL_COMMAND
			__icon = self.ICON_EXTERNAL_COMMAND
		elif __t == child.TYPE_VIM :
			__type = "vim"
			__value = __tab.Child.FILENAME
			__icon = self.ICON_VIM
		elif __t == child.TYPE_GVIM :
			__type = "gvim"
			__value = __tab.Child.FILENAME
			__icon = self.ICON_GVIM
		else :
			return

		if not __value.strip() : return

		# get current tab information.
		__uid = UID.get()

		# prevent the depth from being too deep.
		if len(self.PATH) > 1 :
			self.TREEITER = self.TREESTORE.iter_parent(self.TREEITER)

		#__iter = self.TREESTORE.append( \
		#	self.TREEITER, [_("New Item"), __icon, __uid])
		__iter = self.TREESTORE.append( \
			self.TREEITER, [__value, __icon, __uid])
		__path = self.TREEVIEW.get_model().get_path(__iter)

		#if not self.BOOKMARKS.add( \
		#		__path, __type, __value, _("New Item"), __uid) :
		if not self.BOOKMARKS.add( \
				__path, __type, __value, __value, __uid) :
			return False

		# set cell as editing mode for label.
		if self.TREEITER :
			self.TREEVIEW.expand_row(self.PATH, False)

		column = self.TREEVIEW.get_column(0)
		cell = column.get_cell_renderers()[1]
		cell.set_property("editable", True)
		self.TREEVIEW.set_cursor(__path, column, gtk.TRUE)

		# show the item related items.
		self.WIDGET_RENAME.show()
		self.WIDGET_DELETE.show()

	def on_add_category (self, widget) :

		__uid = UID.get()
		__iter = self.TREESTORE.append(\
			None, [_("New Category"), self.ICON_CATEGORY, __uid])
		__path = self.TREEVIEW.get_model().get_path(__iter)

		if not self.BOOKMARKS.add( \
				__path, "category", None, _("New Category"), __uid) :
			return False

		column = self.TREEVIEW.get_column(0)
		cell = column.get_cell_renderers()[1]
		cell.set_property("editable", True)

		self.TREEVIEW.set_cursor(__path, column, gtk.TRUE)

		# show the item related items.
		self.WIDGET_RENAME.show()
		self.WIDGET_DELETE.show()

		# show the item related items.
		self.WIDGET_RENAME.show()
		self.WIDGET_DELETE.show()

	def on_delete (self, widget) :
		self.TREESTORE.remove(self.TREEITER)
		self.BOOKMARKS.remove(self.PATH)

	def on_rename (self, widget) :
		column = self.TREEVIEW.get_column(0)
		cell = column.get_cell_renderers()[1]
		cell.set_property("editable", True)
		self.TREEVIEW.set_cursor(self.PATH, column, gtk.TRUE)

	def __create_icons (self) :
		__i = gtk.Image()
		__i.set_from_file( \
			os.path.join(Conf.DIR_PIXMAPS, "external-command.png"))
		__image = __i.get_pixbuf().scale_simple(30, 30, 2)
		self.ICON_EXTERNAL_COMMAND = __image

		__i = gtk.Image()
		__i.set_from_file( \
			os.path.join(Conf.DIR_PIXMAPS, "category.png"))
		__image = __i.get_pixbuf().scale_simple(30, 30, 2)
		self.ICON_CATEGORY = __image

		__i = gtk.Image()
		__i.set_from_file( \
			os.path.join(Conf.DIR_PIXMAPS, "terminal.png"))
		__image = __i.get_pixbuf().scale_simple(30, 30, 2)
		self.ICON_TERMINAL = __image

		__i = gtk.Image()
		__i.set_from_file( \
			os.path.join(Conf.DIR_PIXMAPS, "vim.png"))
		__image = __i.get_pixbuf().scale_simple(30, 30, 2)
		self.ICON_VIM = __image

		__i = gtk.Image()
		__i.set_from_file( \
			os.path.join(Conf.DIR_PIXMAPS, "gvim.png"))
		__image = __i.get_pixbuf().scale_simple(30, 30, 2)
		self.ICON_GVIM = __image

"""
Description
-----------


ChangeLog
---------


Usage
-----


"""

__author__ =  "Spike^ekipS <spikeekips@gmail.com>"
__version__=  "0.1"
__nonsense__ = ""

__file__ = "Menu.py"
